update to 4.3.3 rc1

f41
David Tardon 10 years ago
parent 572df5c5a0
commit daaa2f4f77

4
.gitignore vendored

@ -19,6 +19,7 @@
/594eb47b4b1210e25438d51825404d5a-glew-1.10.0.zip
/7681383be6ce489d84c1c74f4e7f9643-liborcus-0.7.0.tar.bz2
/861ef15fa0bc018f9ddc932c4ad8b6dd-lcms2-2.4.tar.gz
/896272c1a9e396b871cb4dffbd694503-mdds_0.11.1.tar.bz2
/a3dcac551fae5ebbec16e844810828c4-libwpd-0.9.9.tar.bz2
/aa5ca9d1ed1082890835afab26400a39-mdds_0.10.3.tar.bz2
/ae330b9493bd4503ac390106ff6060d7-libexttextcat-3.4.3.tar.bz2
@ -97,3 +98,6 @@
/libreoffice-4.3.2.2.tar.xz
/libreoffice-help-4.3.2.2.tar.xz
/libreoffice-translations-4.3.2.2.tar.xz
/libreoffice-4.3.3.1.tar.xz
/libreoffice-help-4.3.3.1.tar.xz
/libreoffice-translations-4.3.3.1.tar.xz

@ -40,11 +40,9 @@ diff --git a/sd/source/ui/view/DocumentRenderer.cxx b/sd/source/ui/view/Document
index 7080e9d..8e1739c 100644
--- a/sd/source/ui/view/DocumentRenderer.cxx
+++ b/sd/source/ui/view/DocumentRenderer.cxx
@@ -1409,7 +1409,9 @@ private:
PrintInfo& rInfo)
{
@@ -1409,6 +1409,7 @@ private:
SdDrawDocument* pDocument = mrBase.GetMainViewShell()->GetDoc();
+ bool bIsDraw = pDocument->GetDocumentType() == DOCUMENT_TYPE_DRAW;
bool bIsDraw = pDocument->GetDocumentType() == DOCUMENT_TYPE_DRAW;
rInfo.meOrientation = ORIENTATION_PORTRAIT;
+ bool bDoDodgyHeightWidthFit = !bIsDraw && !mpOptions->IsNotes();
@ -57,7 +55,7 @@ index 7080e9d..8e1739c 100644
// Draw should abide by specified paper size
Size aPaperSize;
- if (mpOptions->IsDraw())
- if (bIsDraw)
+ if (!bDoDodgyHeightWidthFit)
{
aPaperSize.setWidth(rInfo.maPageSize.Width());
@ -93,15 +91,6 @@ index 7080e9d..8e1739c 100644
}
return true;
@@ -1497,7 +1500,7 @@ private:
aInfo.msTimeDate += GetSdrGlobalData().GetLocaleData()->getTime( Time( Time::SYSTEM ), false, false );
// Draw should use specified paper size when printing
- if (mpOptions->IsDraw())
+ if (mrBase.GetDocShell()->GetDocumentType() == DOCUMENT_TYPE_DRAW)
{
aInfo.maPrintSize = mrBase.GetDocument()->GetSdPage(0, PK_STANDARD)->GetSize();
maPrintSize = awt::Size(aInfo.maPrintSize.Width(),
@@ -1409,6 +1409,7 @@ private:
- // Draw should abide by specified paper size
+ // Draw and Notes should abide by their specified paper size
Size aPaperSize;
--
1.9.3

@ -1,5 +1,5 @@
# download path contains version without the last (fourth) digit
%define libo_version 4.3.2
%define libo_version 4.3.3
# Should contain .alphaX / .betaX, if this is pre-release (actually
# pre-RC) version. The pre-release string is part of tarball file names,
# so we need a way to define it easily at one place.
@ -45,8 +45,8 @@
Summary: Free Software Productivity Suite
Name: libreoffice
Epoch: 1
Version: %{libo_version}.2
Release: 5%{?libo_prerelease}%{?dist}
Version: %{libo_version}.1
Release: 1%{?libo_prerelease}%{?dist}
License: (MPLv1.1 or LGPLv3+) and LGPLv3 and LGPLv2+ and BSD and (MPLv1.1 or GPLv2 or LGPLv2 or Netscape) and Public Domain and ASL 2.0 and Artistic and MPLv2.0 and CC0
Group: Applications/Productivity
URL: http://www.libreoffice.org/
@ -80,7 +80,7 @@ Source12: %{external_url}/bae83fa5dc7f081768daace6e199adc3-glm-0.9.4.6-lib
Source13: %{external_url}/7681383be6ce489d84c1c74f4e7f9643-liborcus-0.7.0.tar.bz2
%global bundling_options %{?bundling_options} --without-system-ucpp --without-system-glew --without-system-glm --without-system-orcus
%if 0%{?rhel} < 7
Source14: %{external_url}/aa5ca9d1ed1082890835afab26400a39-mdds_0.10.3.tar.bz2
Source14: %{external_url}/896272c1a9e396b871cb4dffbd694503-mdds_0.11.1.tar.bz2
Source15: %{external_url}/46e92b68e31e858512b680b3b61dc4c1-mythes-1.2.3.tar.gz
Source16: %{external_url}/32f8e1417a64d3c6f2c727f9053f55ea-redland-1.0.16.tar.gz
Source17: %{external_url}/4ceb9316488b0ea01acf011023cf7fff-raptor2-2.0.9.tar.gz
@ -2291,6 +2291,9 @@ update-desktop-database %{_datadir}/applications &> /dev/null || :
%endif
%changelog
* Thu Oct 09 2014 David Tardon <dtardon@redhat.com> - 1:4.3.3.1-1
- update to 4.3.3 rc1
* Wed Oct 08 2014 Stephan Bergmann <sbergman@redhat.com> - 1:4.3.2.2-5
- Resolves: rhbz#1054952 bad access of smb URLs on KDE

@ -6,6 +6,6 @@ a7983f859eafb2677d7ff386a023bc40 a7983f859eafb2677d7ff386a023bc40-xsltml_2.1.2.
1f24ab1d39f4a51faf22244c94a6203f 1f24ab1d39f4a51faf22244c94a6203f-xmlsec1-1.2.14.tar.gz
0168229624cfac409e766913506961a8 0168229624cfac409e766913506961a8-ucpp-1.3.2.tar.gz
12fb8b5b0d5132726e57b9b9fc7e22c4 libreoffice-multiliblauncher.sh
86aa9cad125fec16c5cd1d9d964e1d20 libreoffice-4.3.2.2.tar.xz
63a59a4c77a72856b47caf1871cfc48f libreoffice-help-4.3.2.2.tar.xz
0236e56349006fc8fec8e7df749c13b1 libreoffice-translations-4.3.2.2.tar.xz
64b0ff6b24b112a76be93fd9e938971e libreoffice-4.3.3.1.tar.xz
402fba6002e6d31036dd2dff0e5b2e2c libreoffice-help-4.3.3.1.tar.xz
c9a8dc73f41a3524085a4508e9f7a37f libreoffice-translations-4.3.3.1.tar.xz

Loading…
Cancel
Save